@@ -61,6 +61,7 @@ import javax.ws.rs.core.Context;
 import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.Response;
 
+import com.openexchange.java.Strings;
 import com.openexchange.mobile.api.facade.auth.AuthenticationService;
 import com.openexchange.mobile.api.facade.auth.LoginCredentials;
 import com.openexchange.mobile.api.facade.auth.SessionData;
@@ -76,7 +77,6 @@ import com.openexchange.mobile.api.facade.services.ConfigService;
 import com.openexchange.mobile.api.facade.utils.CookieUtil;
 import com.openexchange.mobile.api.facade.utils.JacksonUtil;
 import com.openexchange.mobile.api.facade.utils.RequestUtil;
-import com.openexchange.mobile.api.facade.utils.StringUtils;
 
 import lombok.RequiredArgsConstructor;
 import lombok.extern.slf4j.Slf4j;
@@ -105,14 +105,16 @@ public class AuthenticationEndpoint {
         log.info("Authenticating client");
         AuthenticationRequestBody authenticationRequestBody = JacksonUtil.parse(rawRequestBody, AuthenticationRequestBody.class);
         validate(authenticationRequestBody);
+        String hostname = RequestUtil.getHostHeader(request);
         String userAgent = RequestUtil.getUserAgent(request);
-        HostConfiguration configuration = ConfigurationHelper.getConfiguration(request);
+        HostConfiguration configuration = ConfigurationHelper.getConfiguration(hostname);
         RequestUtil.checkUserAgent(userAgent, configuration);
         LoginCredentials credentials = getCredentials(request, authenticationRequestBody)
+                .withHost(hostname)
                 .withUserAgent(userAgent);
         AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
         SessionData sessionData = authenticationService.authenticate(credentials);
-        sessionData = RequestUtil.enhanceSessionData(request, configuration, userAgent, sessionData);
+        sessionData = RequestUtil.enhanceSessionData(request, configuration, hostname, userAgent, sessionData);
         sessionData = configService.addConfiguration(sessionData);
         return buildResponse(sessionData);
     }
@@ -131,10 +133,10 @@ public class AuthenticationEndpoint {
         String username = requestBody.getUsername();
         String password = requestBody.getPassword();
         String clientId = requestBody.getClientId();
-        if (StringUtils.isEmpty(username)) {
+        if (Strings.isEmpty(username)) {
             throw ApiFacadeException.missingParameter("username");
         }
-        if (StringUtils.isEmpty(password)) {
+        if (Strings.isEmpty(password)) {
             throw ApiFacadeException.missingParameter("password");
         }
         if ("".equals(clientId)) {
@@ -154,7 +156,7 @@ public class AuthenticationEndpoint {
         SessionData sessionData = RequestUtil.getSessionData(request);
         HostConfiguration configuration = sessionData.getConfiguration();
         AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
-        LogoutRequestBody requestBody = StringUtils.isEmpty(rawRequestBody)
+        LogoutRequestBody requestBody = Strings.isEmpty(rawRequestBody)
                 ? new LogoutRequestBody(null)
                 : JacksonUtil.parse(rawRequestBody, LogoutRequestBody.class);
         validateLogoutRequestBody(requestBody);
